<?php

namespace Drupal\seo_alt_hreflang\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure alternative hreflang settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'seo_alt_hreflang_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['seo_alt_hreflang.settings'];
  }

  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $languages = \Drupal::languageManager()->getLanguages();
    $form['seo_alt_hreflang'] = [
      '#type' => 'fieldset',
      '#title' => t('Alternative Hreflang Language Codes'),
      '#tree' => TRUE,
    ];
    $hreflangValues = $this->config('seo_alt_hreflang.settings')
      ->get('seo_alt_hreflang_list');
    foreach ($languages as $langcode => $language) {
      $form['seo_alt_hreflang'][$langcode] = [
        '#type' => 'textfield',
        '#title' => $language->getName() . ' (' . $langcode . ')',
        '#default_value' => $hreflangValues[$langcode] ?? NULL,
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $conf = $this->config('seo_alt_hreflang.settings');
    $values = $form_state->getValue('seo_alt_hreflang');
    $values = array_filter(array_map('trim', array_filter($values)));
    if (!empty($values)) {
      $conf->set('seo_alt_hreflang_list', $values);
    }
    $conf->save();
    parent::submitForm($form, $form_state);
  }

}
